==> android-aihelp-aar-3.3.12-sources.jar: net/aihelp/data/model/init/InitEntity.java <==
package net.aihelp.data.model.init;


public class InitEntity {

    /**
     * 上传视频开关
     */
    private boolean isOpenVideoUpload;
    private boolean isSetCrmToken;
    private boolean isOpenUploadLogFile;
    private boolean isUnreadMessage;
    private boolean isOpenPushServer;
    private boolean isLocalizeFAQViaInit;
    private int unreadMessageTime;
    private int videoUploadSizeLimit;
    private int initPeriod;
    private PrivacyControlEntity customInformation;
    private NetworkCheckSettingBean networkCheckSetting;
    private String svrip;
    private String svrport;
    private String vipChatDomain;
    private String pushServer;
    private String topic;
    private String upload;
    private String uploadVideo;
    private String uploadLog;
    private String point;
    private String faqdata;
    private String faqYYdata;
    private String faqdataForm;
    private String cdnUrl;
    private String faqAimlFileName;
    private String storyAimlFileName;
    private String faqFileName;
    private String operateFileName;
    private String showfaq;
    private String configFileName;
    private int requestLimit = -1;
    private String correctLanguage;
    private boolean tls;
    private String localeFile;
    private boolean isTranslates;

    /**
     * 新版 UI 自定义 - 样式表
     */
    private String configStyle;

    /**
     * 新版 UI 自定义 - 开关
     */
    private String configBusiness;

    /**
     * 新版 UI 自定义 - 自定义负反馈选项
     */
    private String satisfyFeedback;

    /**
     * 新版 UI 自定义 - FAQ 首页数据
     */
    private String configFaq;

    /**
     * 新版 UI 自定义 - 流程定制
     */
    private String configProcess;

    /**
     * 新版 UI 自定义 - 文本
     */
    private String configText;

    public String getConfigStyle() {
        return configStyle;
    }

    public void setConfigStyle(String configStyle) {
        this.configStyle = configStyle;
    }

    public String getConfigBusiness() {
        return configBusiness;
    }

    public void setConfigBusiness(String configBusiness) {
        this.configBusiness = configBusiness;
    }

    public String getSatisfyFeedback() {
        return satisfyFeedback;
    }

    public void setSatisfyFeedback(String satisfyFeedback) {
        this.satisfyFeedback = satisfyFeedback;
    }

    public String getConfigFaq() {
        return configFaq;
    }

    public void setConfigFaq(String configFaq) {
        this.configFaq = configFaq;
    }

    public String getConfigProcess() {
        return configProcess;
    }

    public void setConfigProcess(String configProcess) {
        this.configProcess = configProcess;
    }

    public String getConfigText() {
        return configText;
    }

    public void setConfigText(String configText) {
        this.configText = configText;
    }

    public boolean isTranslates() {
        return isTranslates;
    }

    public void setTranslates(boolean translates) {
        isTranslates = translates;
    }

    public String getLocaleFile() {
        return localeFile;
    }

    public void setLocaleFile(String localeFile) {
        this.localeFile = localeFile;
    }

    public boolean isTls() {
        return tls;
    }

    public void setTls(boolean tls) {
        this.tls = tls;
    }

    public String getCorrectLanguage() {
        return correctLanguage;
    }

    public void setCorrectLanguage(String correctLanguage) {
        this.correctLanguage = correctLanguage;
    }

    public String getConfigFileName() {
        return configFileName;
    }

    public void setConfigFileName(String configFileName) {
        this.configFileName = configFileName;
    }

    public boolean isLocalizeFAQViaInit() {
        return isLocalizeFAQViaInit;
    }

    public void setLocalizeFAQViaInit(boolean localizeFAQViaInit) {
        isLocalizeFAQViaInit = localizeFAQViaInit;
    }

    public int getRequestLimit() {
        return requestLimit;
    }

    public void setRequestLimit(int requestLimit) {
        this.requestLimit = requestLimit;
    }

    public boolean isOpenVideoUpload() {
        return isOpenVideoUpload;
    }

    public void setOpenVideoUpload(boolean isOpenVideoUpload) {
        this.isOpenVideoUpload = isOpenVideoUpload;
    }

    public boolean isSetCrmToken() {
        return isSetCrmToken;
    }

    public void setSetCrmToken(boolean isSetCrmToken) {
        this.isSetCrmToken = isSetCrmToken;
    }

    public boolean isOpenUploadLogFile() {
        return isOpenUploadLogFile;
    }

    public void setOpenUploadLogFile(boolean isOpenUploadLogFile) {
        this.isOpenUploadLogFile = isOpenUploadLogFile;
    }

    public boolean isUnreadMessage() {
        return isUnreadMessage;
    }

    public void setUnreadMessage(boolean isUnreadMessage) {
        this.isUnreadMessage = isUnreadMessage;
    }

    public boolean isOpenPushServer() {
        return isOpenPushServer;
    }

    public void setOpenPushServer(boolean isOpenPushServer) {
        this.isOpenPushServer = isOpenPushServer;
    }

    public int getUnreadMessageTime() {
        return unreadMessageTime;
    }

    public void setUnreadMessageTime(int unreadMessageTime) {
        this.unreadMessageTime = unreadMessageTime;
    }

    public int getVideoUploadSizeLimit() {
        return videoUploadSizeLimit;
    }

    public void setVideoUploadSizeLimit(int videoUploadSizeLimit) {
        this.videoUploadSizeLimit = videoUploadSizeLimit;
    }

    public int getInitPeriod() {
        return initPeriod;
    }

    public void setInitPeriod(int initPeriod) {
        this.initPeriod = initPeriod;
    }

    public PrivacyControlEntity getCustomInformation() {
        return customInformation;
    }

    public void setCustomInformation(PrivacyControlEntity customInformation) {
        this.customInformation = customInformation;
    }

    public NetworkCheckSettingBean getNetworkCheckSetting() {
        return networkCheckSetting;
    }

    public void setNetworkCheckSetting(NetworkCheckSettingBean networkCheckSetting) {
        this.networkCheckSetting = networkCheckSetting;
    }

    public String getSvrip() {
        return svrip;
    }

    public void setSvrip(String svrip) {
        this.svrip = svrip;
    }

    public String getSvrport() {
        return svrport;
    }

    public void setSvrport(String svrport) {
        this.svrport = svrport;
    }

    public String getVipChatDomain() {
        return vipChatDomain;
    }

    public void setVipChatDomain(String vipChatDomain) {
        this.vipChatDomain = vipChatDomain;
    }

    public String getPushServer() {
        return pushServer;
    }

    public void setPushServer(String pushServer) {
        this.pushServer = pushServer;
    }

    public String getTopic() {
        return topic;
    }

    public void setTopic(String topic) {
        this.topic = topic;
    }

    public String getUpload() {
        return upload;
    }

    public void setUpload(String upload) {
        this.upload = upload;
    }

    public String getUploadVideo() {
        return uploadVideo;
    }

    public void setUploadVideo(String uploadVideo) {
        this.uploadVideo = uploadVideo;
    }

    public String getUploadLog() {
        return uploadLog;
    }

    public void setUploadLog(String uploadLog) {
        this.uploadLog = uploadLog;
    }

    public String getPoint() {
        return point;
    }

    public void setPoint(String point) {
        this.point = point;
    }

    public String getFaqdata() {
        return faqdata;
    }

    public void setFaqdata(String faqdata) {
        this.faqdata = faqdata;
    }

    public String getFaqYYdata() {
        return faqYYdata;
    }

    public void setFaqYYdata(String faqYYdata) {
        this.faqYYdata = faqYYdata;
    }

    public String getFaqdataForm() {
        return faqdataForm;
    }

    public void setFaqdataForm(String faqdataForm) {
        this.faqdataForm = faqdataForm;
    }

    public String getCdnUrl() {
        return cdnUrl;
    }

    public void setCdnUrl(String cdnUrl) {
        this.cdnUrl = cdnUrl;
    }

    public String getFaqAimlFileName() {
        return faqAimlFileName;
    }

    public void setFaqAimlFileName(String faqAimlFileName) {
        this.faqAimlFileName = faqAimlFileName;
    }

    public String getStoryAimlFileName() {
        return storyAimlFileName;
    }

    public void setStoryAimlFileName(String storyAimlFileName) {
        this.storyAimlFileName = storyAimlFileName;
    }

    public String getFaqFileName() {
        return faqFileName;
    }

    public void setFaqFileName(String faqFileName) {
        this.faqFileName = faqFileName;
    }

    public String getOperateFileName() {
        return operateFileName;
    }

    public void setOperateFileName(String operateFileName) {
        this.operateFileName = operateFileName;
    }

    public String getShowfaq() {
        return showfaq;
    }

    public void setShowfaq(String showfaq) {
        this.showfaq = showfaq;
    }

    public static class NetworkCheckSettingBean {
        /**
         * ping : 举报,优秀案例,账号
         * traceroute : account is frozen,account lost,account stolen,BIG,contact
         */

        private String ping;
        private String traceroute;

        public String getPing() {
            return ping;
        }

        public void setPing(String ping) {
            this.ping = ping;
        }

        public String getTraceroute() {
            return traceroute;
        }

        public void setTraceroute(String traceroute) {
            this.traceroute = traceroute;
        }
    }

}

==> android-aihelp-aar-3.5.4-sources.jar: net/aihelp/data/model/init/InitEntity.java <==
package net.aihelp.data.model.init;


public class InitEntity {

    /**
     * 上传视频开关
     */
    private boolean isOpenVideoUpload;
    private boolean isSetCrmToken;
    private boolean isOpenUploadLogFile;
    private boolean isUnreadMessage;
    private boolean isOpenPushServer;
    private boolean isLocalizeFAQViaInit;
    private int unreadMessageTime;
    private int videoUploadSizeLimit;
    private int initPeriod;
    private PrivacyControlEntity customInformation;
    private NetworkCheckSettingBean networkCheckSetting;
    private String svrip;
    private String svrport;
    private String vipChatDomain;
    private String pushServer;
    private String topic;
    private String upload;
    private String uploadVideo;
    private String uploadLog;
    private String point;
    private String faqdata;
    private String faqYYdata;
    private String faqdataForm;
    private String cdnUrl;
    private String faqAimlFileName;
    private String storyAimlFileName;
    private String faqFileName;
    private String operateFileName;
    private String showfaq;
    private String configFileName;
    private int requestLimit = -1;
    private String correctLanguage;
    private boolean tls;
    private String localeFile;
    private boolean isTranslates;

    /**
     * 新版 UI 自定义 - 样式表
     */
    private String configStyle;

    /**
     * 新版 UI 自定义 - 开关
     */
    private String configBusiness;

    /**
     * 新版 UI 自定义 - 自定义负反馈选项
     */
    private String satisfyFeedback;

    /**
     * 新版 UI 自定义 - FAQ 首页数据
     */
    private String configFaq;

    /**
     * 新版 UI 自定义 - 流程定制
     */
    private String configProcess;

    /**
     * 新版 UI 自定义 - 文本
     */
    private String configText;

    private boolean isShowMyTask;

    public boolean isShowMyTask() {
        return isShowMyTask;
    }

    public void setShowMyTask(boolean showMyTask) {
        isShowMyTask = showMyTask;
    }

    public String getConfigStyle() {
        return configStyle;
    }

    public void setConfigStyle(String configStyle) {
        this.configStyle = configStyle;
    }

    public String getConfigBusiness() {
        return configBusiness;
    }

    public void setConfigBusiness(String configBusiness) {
        this.configBusiness = configBusiness;
    }

    public String getSatisfyFeedback() {
        return satisfyFeedback;
    }

    public void setSatisfyFeedback(String satisfyFeedback) {
        this.satisfyFeedback = satisfyFeedback;
    }

    public String getConfigFaq() {
        return configFaq;
    }

    public void setConfigFaq(String configFaq) {
        this.configFaq = configFaq;
    }

    public String getConfigProcess() {
        return configProcess;
    }

    public void setConfigProcess(String configProcess) {
        this.configProcess = configProcess;
    }

    public String getConfigText() {
        return configText;
    }

    public void setConfigText(String configText) {
        this.configText = configText;
    }

    public boolean isTranslates() {
        return isTranslates;
    }

    public void setTranslates(boolean translates) {
        isTranslates = translates;
    }

    public String getLocaleFile() {
        return localeFile;
    }

    public void setLocaleFile(String localeFile) {
        this.localeFile = localeFile;
    }

    public boolean isTls() {
        return tls;
    }

    public void setTls(boolean tls) {
        this.tls = tls;
    }

    public String getCorrectLanguage() {
        return correctLanguage;
    }

    public void setCorrectLanguage(String correctLanguage) {
        this.correctLanguage = correctLanguage;
    }

    public String getConfigFileName() {
        return configFileName;
    }

    public void setConfigFileName(String configFileName) {
        this.configFileName = configFileName;
    }

    public boolean isLocalizeFAQViaInit() {
        return isLocalizeFAQViaInit;
    }

    public void setLocalizeFAQViaInit(boolean localizeFAQViaInit) {
        isLocalizeFAQViaInit = localizeFAQViaInit;
    }

    public int getRequestLimit() {
        return requestLimit;
    }

    public void setRequestLimit(int requestLimit) {
        this.requestLimit = requestLimit;
    }

    public boolean isOpenVideoUpload() {
        return isOpenVideoUpload;
    }

    public void setOpenVideoUpload(boolean isOpenVideoUpload) {
        this.isOpenVideoUpload = isOpenVideoUpload;
    }

    public boolean isSetCrmToken() {
        return isSetCrmToken;
    }

    public void setSetCrmToken(boolean isSetCrmToken) {
        this.isSetCrmToken = isSetCrmToken;
    }

    public boolean isOpenUploadLogFile() {
        return isOpenUploadLogFile;
    }

    public void setOpenUploadLogFile(boolean isOpenUploadLogFile) {
        this.isOpenUploadLogFile = isOpenUploadLogFile;
    }

    public boolean isUnreadMessage() {
        return isUnreadMessage;
    }

    public void setUnreadMessage(boolean isUnreadMessage) {
        this.isUnreadMessage = isUnreadMessage;
    }

    public boolean isOpenPushServer() {
        return isOpenPushServer;
    }

    public void setOpenPushServer(boolean isOpenPushServer) {
        this.isOpenPushServer = isOpenPushServer;
    }

    public int getUnreadMessageTime() {
        return unreadMessageTime;
    }

    public void setUnreadMessageTime(int unreadMessageTime) {
        this.unreadMessageTime = unreadMessageTime;
    }

    public int getVideoUploadSizeLimit() {
        return videoUploadSizeLimit;
    }

    public void setVideoUploadSizeLimit(int videoUploadSizeLimit) {
        this.videoUploadSizeLimit = videoUploadSizeLimit;
    }

    public int getInitPeriod() {
        return initPeriod;
    }

    public void setInitPeriod(int initPeriod) {
        this.initPeriod = initPeriod;
    }

    public PrivacyControlEntity getCustomInformation() {
        return customInformation;
    }

    public void setCustomInformation(PrivacyControlEntity customInformation) {
        this.customInformation = customInformation;
    }

    public NetworkCheckSettingBean getNetworkCheckSetting() {
        return networkCheckSetting;
    }

    public void setNetworkCheckSetting(NetworkCheckSettingBean networkCheckSetting) {
        this.networkCheckSetting = networkCheckSetting;
    }

    public String getSvrip() {
        return svrip;
    }

    public void setSvrip(String svrip) {
        this.svrip = svrip;
    }

    public String getSvrport() {
        return svrport;
    }

    public void setSvrport(String svrport) {
        this.svrport = svrport;
    }

    public String getVipChatDomain() {
        return vipChatDomain;
    }

    public void setVipChatDomain(String vipChatDomain) {
        this.vipChatDomain = vipChatDomain;
    }

    public String getPushServer() {
        return pushServer;
    }

    public void setPushServer(String pushServer) {
        this.pushServer = pushServer;
    }

    public String getTopic() {
        return topic;
    }

    public void setTopic(String topic) {
        this.topic = topic;
    }

    public String getUpload() {
        return upload;
    }

    public void setUpload(String upload) {
        this.upload = upload;
    }

    public String getUploadVideo() {
        return uploadVideo;
    }

    public void setUploadVideo(String uploadVideo) {
        this.uploadVideo = uploadVideo;
    }

    public String getUploadLog() {
        return uploadLog;
    }

    public void setUploadLog(String uploadLog) {
        this.uploadLog = uploadLog;
    }

    public String getPoint() {
        return point;
    }

    public void setPoint(String point) {
        this.point = point;
    }

    public String getFaqdata() {
        return faqdata;
    }

    public void setFaqdata(String faqdata) {
        this.faqdata = faqdata;
    }

    public String getFaqYYdata() {
        return faqYYdata;
    }

    public void setFaqYYdata(String faqYYdata) {
        this.faqYYdata = faqYYdata;
    }

    public String getFaqdataForm() {
        return faqdataForm;
    }

    public void setFaqdataForm(String faqdataForm) {
        this.faqdataForm = faqdataForm;
    }

    public String getCdnUrl() {
        return cdnUrl;
    }

    public void setCdnUrl(String cdnUrl) {
        this.cdnUrl = cdnUrl;
    }

    public String getFaqAimlFileName() {
        return faqAimlFileName;
    }

    public void setFaqAimlFileName(String faqAimlFileName) {
        this.faqAimlFileName = faqAimlFileName;
    }

    public String getStoryAimlFileName() {
        return storyAimlFileName;
    }

    public void setStoryAimlFileName(String storyAimlFileName) {
        this.storyAimlFileName = storyAimlFileName;
    }

    public String getFaqFileName() {
        return faqFileName;
    }

    public void setFaqFileName(String faqFileName) {
        this.faqFileName = faqFileName;
    }

    public String getOperateFileName() {
        return operateFileName;
    }

    public void setOperateFileName(String operateFileName) {
        this.operateFileName = operateFileName;
    }

    public String getShowfaq() {
        return showfaq;
    }

    public void setShowfaq(String showfaq) {
        this.showfaq = showfaq;
    }

    public static class NetworkCheckSettingBean {
        /**
         * ping : 举报,优秀案例,账号
         * traceroute : account is frozen,account lost,account stolen,BIG,contact
         */

        private String ping;
        private String traceroute;

        public String getPing() {
            return ping;
        }

        public void setPing(String ping) {
            this.ping = ping;
        }

        public String getTraceroute() {
            return traceroute;
        }

        public void setTraceroute(String traceroute) {
            this.traceroute = traceroute;
        }
    }

}
